# Python common

[![Documentation Status](https://readthedocs.org/projects/cyb3rjak3-common/badge/?version=latest)](https://common-py.docs.jwhite.network/en/latest/?badge=latest) [![Python Checking](https://github.com/Cyb3r-Jak3/common-python/actions/workflows/python.yml/badge.svg)](https://github.com/Cyb3r-Jak3/common-python/actions/workflows/python.yml)

This is common python code that I use between my programs. I also have [common-go](https://github.com/Cyb3r-Jak3/common-go) for common go code.
Documentation is available via [readthedocs](https://common-py.docs.jwhite.network)

To make this smaller there are no requirements but certain functions will require other modules and will raise ModuleNotFoundError if a function is used

